==> 1.2025.316.6.tar.gz: OBJECTS/gen/content/browser/resources/indexed_db/tsc/database.js <==
// Copyright 2024 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import './transaction_table.js';
import { CustomElement } from 'chrome://resources/js/custom_element.js';
import { mojoString16ToString } from 'chrome://resources/js/mojo_type_util.js';
import { getTemplate } from './database.html.js';
import { IdbInternalsHandler } from './indexed_db_internals.mojom-webui.js';
export class IndexedDbDatabase extends CustomElement {
    clients;
    static get template() {
        return getTemplate();
    }
    // Similar to CustomElement.$, but asserts that the element exists.
    $a(query) {
        return this.getRequiredElement(query);
    }
    // Setter for `data` property. Updates the component contents with the
    // provided metadata.
    set data(metadata) {
        const openDatabasesElement = this.$a('.open-databases');
        const openConnectionElement = this.$a('.connection-count.open');
        const activeConnectionElement = this.$a('.connection-count.active');
        const pendingConnectionElement = this.$a('.connection-count.pending');
        openDatabasesElement.textContent = mojoString16ToString(metadata.name);
        openConnectionElement.hidden = metadata.connectionCount === 0n;
        openConnectionElement.querySelector('.value').textContent =
            metadata.connectionCount.toString();
        activeConnectionElement.hidden = metadata.activeOpenDelete === 0n;
        activeConnectionElement.querySelector('.value').textContent =
            metadata.activeOpenDelete.toString();
        pendingConnectionElement.hidden = metadata.pendingOpenDelete === 0n;
        pendingConnectionElement.querySelector('.value').textContent =
            metadata.pendingOpenDelete.toString();
        this.groupAndShowTransactionsByClient(metadata.transactions);
    }
    groupAndShowTransactionsByClient(transactions) {
        const groupedTransactions = new Map();
        for (const transaction of transactions) {
            const client = transaction.clientToken;
            if (!groupedTransactions.has(client)) {
                groupedTransactions.set(client, []);
            }
            groupedTransactions.get(client).push(transaction);
        }
        const transactionsBlockElement = this.$a('#transactions');
        transactionsBlockElement.textContent = '';
        for (const [clientToken, clientTransactions] of groupedTransactions) {
            const container = this.createClientTransactionsContainer(clientToken, clientTransactions);
            container.classList.add('metadata-list-item');
            transactionsBlockElement.appendChild(container);
        }
    }
    // Creates a div containing an instantiation of the client metadata template
    // and a table of transactions.
    createClientTransactionsContainer(clientToken, transactions) {
        const clientMetadataTemplate = this.$a('#client-metadata');
        const clientMetadata = clientMetadataTemplate.content.cloneNode(true);
        clientMetadata.querySelector('.client-id').textContent = clientToken;
        clientMetadata.querySelector('.control.inspect').addEventListener('click', () => {
            // If there are non-zero clients, inspecting any of them should have
            // the same effect.
            const client = this.getClientsMatchingToken(clientToken).pop();
            if (!client) {
                return;
            }
            IdbInternalsHandler.getRemote()
                .inspectClient(client)
                .then(message => {
                if (message.error) {
                    console.error(message.error);
                }
            })
                .catch(errorMsg => console.error(errorMsg));
        });
        const transactionTable = document.createElement('indexeddb-transaction-table');
        transactionTable.transactions = transactions;
        const container = document.createElement('div');
        container.appendChild(clientMetadata);
        container.appendChild(transactionTable);
        return container;
    }
    // Returns the list of clients whose `documentToken` or `contextToken` matches
    // the supplied `token`.
    getClientsMatchingToken(token) {
        const matchedClients = [];
        for (const client of this.clients) {
            const tokenValue = client.documentToken ?
                client.documentToken.value :
                this.getExecutionContextTokenValue(client.contextToken);
            if (tokenValue && tokenValue === token) {
                matchedClients.push(client);
            }
        }
        return matchedClients;
    }
    getExecutionContextTokenValue(token) {
        if (token.localFrameToken) {
            return token.localFrameToken.value;
        }
        if (token.dedicatedWorkerToken) {
            return token.dedicatedWorkerToken.value;
        }
        if (token.serviceWorkerToken) {
            return token.serviceWorkerToken.value;
        }
        if (token.sharedWorkerToken) {
            return token.sharedWorkerToken.value;
        }
        throw new Error('Unrecognized ExecutionContextToken');
    }
}
customElements.define('indexeddb-database', IndexedDbDatabase);

==> 1.2025.323.6.tar.gz: OBJECTS/gen/content/browser/resources/indexed_db/tsc/database.js <==
// Copyright 2024 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import './transaction_table.js';
import { CustomElement } from 'chrome://resources/js/custom_element.js';
import { getTemplate } from './database.html.js';
import { IdbInternalsHandler } from './indexed_db_internals.mojom-webui.js';
export class IndexedDbDatabase extends CustomElement {
    clients;
    static get template() {
        return getTemplate();
    }
    // Similar to CustomElement.$, but asserts that the element exists.
    $a(query) {
        return this.getRequiredElement(query);
    }
    // Setter for `data` property. Updates the component contents with the
    // provided metadata.
    set data(metadata) {
        const openDatabasesElement = this.$a('.open-databases');
        const openConnectionElement = this.$a('.connection-count.open');
        const activeConnectionElement = this.$a('.connection-count.active');
        const pendingConnectionElement = this.$a('.connection-count.pending');
        openDatabasesElement.textContent = metadata.name;
        openConnectionElement.hidden = metadata.connectionCount === 0n;
        openConnectionElement.querySelector('.value').textContent =
            metadata.connectionCount.toString();
        activeConnectionElement.hidden = metadata.activeOpenDelete === 0n;
        activeConnectionElement.querySelector('.value').textContent =
            metadata.activeOpenDelete.toString();
        pendingConnectionElement.hidden = metadata.pendingOpenDelete === 0n;
        pendingConnectionElement.querySelector('.value').textContent =
            metadata.pendingOpenDelete.toString();
        this.groupAndShowTransactionsByClient(metadata.transactions);
    }
    groupAndShowTransactionsByClient(transactions) {
        const groupedTransactions = new Map();
        for (const transaction of transactions) {
            const client = transaction.clientToken;
            if (!groupedTransactions.has(client)) {
                groupedTransactions.set(client, []);
            }
            groupedTransactions.get(client).push(transaction);
        }
        const transactionsBlockElement = this.$a('#transactions');
        transactionsBlockElement.textContent = '';
        for (const [clientToken, clientTransactions] of groupedTransactions) {
            const container = this.createClientTransactionsContainer(clientToken, clientTransactions);
            container.classList.add('metadata-list-item');
            transactionsBlockElement.appendChild(container);
        }
    }
    // Creates a div containing an instantiation of the client metadata template
    // and a table of transactions.
    createClientTransactionsContainer(clientToken, transactions) {
        const clientMetadataTemplate = this.$a('#client-metadata');
        const clientMetadata = clientMetadataTemplate.content.cloneNode(true);
        clientMetadata.querySelector('.client-id').textContent = clientToken;
        clientMetadata.querySelector('.control.inspect').addEventListener('click', () => {
            // If there are non-zero clients, inspecting any of them should have
            // the same effect.
            const client = this.getClientsMatchingToken(clientToken).pop();
            if (!client) {
                return;
            }
            IdbInternalsHandler.getRemote()
                .inspectClient(client)
                .then(message => {
                if (message.error) {
                    console.error(message.error);
                }
            })
                .catch(errorMsg => console.error(errorMsg));
        });
        const transactionTable = document.createElement('indexeddb-transaction-table');
        transactionTable.transactions = transactions;
        const container = document.createElement('div');
        container.appendChild(clientMetadata);
        container.appendChild(transactionTable);
        return container;
    }
    // Returns the list of clients whose `documentToken` or `contextToken` matches
    // the supplied `token`.
    getClientsMatchingToken(token) {
        const matchedClients = [];
        for (const client of this.clients) {
            const tokenValue = client.documentToken ?
                client.documentToken.value :
                this.getExecutionContextTokenValue(client.contextToken);
            if (tokenValue && tokenValue === token) {
                matchedClients.push(client);
            }
        }
        return matchedClients;
    }
    getExecutionContextTokenValue(token) {
        if (token.localFrameToken) {
            return token.localFrameToken.value;
        }
        if (token.dedicatedWorkerToken) {
            return token.dedicatedWorkerToken.value;
        }
        if (token.serviceWorkerToken) {
            return token.serviceWorkerToken.value;
        }
        if (token.sharedWorkerToken) {
            return token.sharedWorkerToken.value;
        }
        throw new Error('Unrecognized ExecutionContextToken');
    }
}
customElements.define('indexeddb-database', IndexedDbDatabase);
